@@ -51,7 +51,7 @@ OPCr <- function(plyFile, Steps=8, stepSize=5.625, minimum_faces=3, minimum_area
     Dummy <- capture.output(Run <- OPC(plyFile=plyFile, rotation=j, minimum_faces=minimum_faces,
                                        minimum_area=minimum_area))
     Values <- unlist(strsplit(grep(c(" "), Dummy, value=TRUE), " "))
-    Output[i,2] <- as.numeric(Values[4])
+    Output[i,2] <- as.numeric(Values[6])
     Output[i,1] <- j
     j <- j + stepSize
     gc(verbose=FALSE)
@@ -61,6 +61,6 @@ OPCr <- function(plyFile, Steps=8, stepSize=5.625, minimum_faces=3, minimum_area
   Result <- round(mean(Output[,2]), 2)
   
   out <- list("OPCR"=Result, "Each_Run"=Output)
-  cat("Average patch count after", Steps, "OPC calculations at", stepSize, "degrees \nrotated between each calculation =", Result)
+  cat("Average patch count after", Steps, "OPC calculations at", stepSize, "degrees \nrotated between each calculation =", Result, "\n")
   return(out)
 }
\ No newline at end of file
